/******************************************************************/
/*                                                                */
/* Program: imf2tga.c                                             */
/*                                                                */
/* Description:                                                   */
/*                                                                */
/* This program converts a 16 bit GOP greyscale-image (*.imf) to  */
/* to a 24 bit RGB Targa file (*.tga).                            */
/* UNIX version.                                                  */
/*                                                                */
/* Program by:    Stefan Spaennare, Lund, Sweden                  */
/* E-mail:        stefan@spaennare.se                             */
/*                                                                */
/* First version: October 1995                                    */
/* Latest update: 1998-06-05                                      */
/*                                                                */
/******************************************************************/

/*****************************************************************************/
/*                                                                           */
/* Notice:                                                                   */
/* =======                                                                   */
/*                                                                           */
/* I make no warranties that this program is (1) free of error, (2) con-     */
/* sistent with any standard merchantability, or (3) meeting the require-    */
/* ments of a particular application.  This software shall not, partly or    */
/* as a whole, participate in a process, whose outcome can result in injury  */
/* to a person or loss of property. It is solely designed for analytical     */
/* work.  Permission to use, copy, and distribute is hereby granted without  */
/* fee, providing that the header above including this notice appears in     */
/* all copies.                                                               */
/*                                                                           */
/*                                                         Stefan Spaennare  */
/*                                                                           */
/*****************************************************************************/

#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "image.h"


int main(argc,argv) 
int argc;
char *argv[];
{
   struct image_head header; 
   short **image;

   FILE *outfile;
   
   int i,j,k,n,rgb,xsize,ysize,temp;
   int lll,hhh;
  
   unsigned char d[4];

   unsigned short ss[10];


   if (argc<3) {
      printf("Usage: %s gopimage image.tga\n",argv[0]);
      exit(0);
   } /* if */

 
   ReadHeader(argv[1],&header);

   image = (short **)calloc(header.hgh,sizeof(short*));

   ReadImage(argv[1],image);

   outfile = fopen(argv[2],"wb");

   xsize=header.wid;
   ysize=header.hgh;


   ss[1]=0;
   ss[2]=512;
   ss[3]=0;
   ss[4]=0;
   ss[5]=0;
   ss[6]=0;
   hhh=xsize / 256;
   lll=xsize % 256;
   ss[7]=lll*256+hhh;
   hhh=ysize / 256;
   lll=ysize % 256;
   ss[8]=lll*256+hhh;
   ss[9]=6176;


   fwrite(&ss[1],sizeof(unsigned short),9,outfile);

   printf("%6d %6d\n",xsize,ysize);
 
   for (i=0; i<ysize; i++) {
      for (j=0; j<xsize; j++) {
          temp=image[i][j]/128;
          d[1]=temp;
          d[2]=temp;
          d[3]=temp;
          fwrite(&d[1],sizeof(unsigned char),3,outfile);
      } /* for j */
   } /* for i */


   fclose(outfile);


} /* End  */
